Authors — RocketCEA v1.1.25 documentation

# Authors

Thank you for supporting RocketCEA.

## Development Lead

- Charlie Taylor

## Patches and Ideas

- stepbot

    - MacOS support

- mahoep

    - Added transport properties and temperatures of throat and exit (see get_Temperatures function)

## Initial Project Layout

RocketCEA Framework was Created by: PyHatch

(PyHatch Initializes Files And Directory Structures For New Python Projects.)

See PyHatch Docs at: http://pyhatch.readthedocs.org/en/latest/